@@ -40,6 +40,7 @@ MainView::MainView(QWidget *parent) :
 
     acceptDrag = false;
     rejectDrag = false;
+    _acceptMousePress = false;
 
 
     numberLabel = new QLabel(this);
@@ -67,11 +68,13 @@ MainView::MainView(QWidget *parent) :
     redArrow->setGeometry(width() - rejectButton->width() - 10 - 55, acceptButton->pos().y() + acceptButton->height()/2 -4, 55, 14);
     redArrow->setStyleSheet(QString(_style + "/images/redarrow.png)"));
     redArrow->setAutoFillBackground(true);
-
 }
 
 void MainView::mousePressEvent(QMouseEvent *event)
 {
+    if(!_acceptMousePress)
+        return;
+
     offset = event->pos();
     if(offset.y() > 500 && offset.y() < 750 && offset.x() < acceptButton->width())
     {
@@ -128,3 +131,13 @@ void MainView::setName(const QString &name)
 {
     nameLabel->setText(name);
 }
+
+void MainView::acceptMousePress()
+{
+    _acceptMousePress = true;
+}
+
+void MainView::rejectMousePress()
+{
+    _acceptMousePress = false;
+}
