@@ -20,6 +20,7 @@ private:
     int xpos;
     bool acceptDrag;
     bool rejectDrag;
+    bool _acceptMousePress;
     QWidget *acceptButton;
     QWidget *rejectButton;
     QLabel *numberLabel;
@@ -34,7 +35,8 @@ signals:
 public slots:
     void setNumber(const QString &number);
     void setName(const QString &name);
-    
+    void acceptMousePress();
+    void rejectMousePress();
 };
 
 #endif // MAINVIEW_H
