@@ -2,6 +2,7 @@
 #define MAINWIN_H
 
 #include <QGraphicsView>
+#include <QCoreApplication>
 #include <QtDBus>
 #include <QDebug>
 #include <QtGui>
@@ -14,6 +15,7 @@
 #include <QApplication>
 #include <QDesktopWidget>
 #include <QCloseEvent>
+#include <QEvent>
 #include <QGraphicsScene>
 #include <QGraphicsProxyWidget>
 #include <libintl.h>
@@ -30,7 +32,11 @@ class MainWin : public QGraphicsView
 public:
     explicit MainWin(QWidget *parent = 0);
     ~MainWin();
-    
+
+    static bool myEventFilter(void *message, long int *);
+    static const MainWin* instance();
+    static MainWin *_mainWin;
+
 private:
     QGraphicsScene *scene;
     QGraphicsProxyWidget *proxy;
@@ -63,7 +69,7 @@ public slots:
     void hildonRestoreRotation();
     void setDBus();
     void setXProperties();
-    void changeEvent(QEvent *event);
+    //void changeEvent(QEvent *event); //ahh ... QEvent::ActivationChange is not send in locked state
 };
 
 #endif // MAINWIN_H
